@@ -36,11 +36,13 @@ from dbsprockets.util import freshdefaults
 from warnings import warn
 
 import sqlalchemy
-saVersion = int(sqlalchemy.__version__.split('.')[1])
+#saVersion = int(sqlalchemy.__version__.split('.')[1])
 
-if saVersion>4:
+try:
     from sqlalchemy.orm.attributes import ClassManager
-else:
+    saVersion=5
+except ImportError:
+    saVersion = int(sqlalchemy.__version__.split('.')[1])
     warn('Versions of dbsprockets>=0.5 will require sqlalchemy>=0.5')
 
 class DBHelper:
